%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CancerFit
% 
% Reference: Fetal/Juvenile Tumor Initiation (2010)
% Authors: Kini, L.G., Herrero-Jimenez P., Guitterez Jr E., Hensle, D.,
%    Kogel J., Kusko R., Rexer, K., Kurzweil, R., Gostjeva, E., 
%    Morgenthaler, S., and Thilly WG.
% Contact: Lohith Kini <lkini (AT) mit DOT edu>
% Version: 5.0
% Last modified: March 22, 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function varargout = CancerFit(varargin)
% CANCERFIT allows for the computation of best fits to Cancer Mortality
% incidence data available at epidemiology.mit.edu . For more information,
% refer to Kini et al (2010) or visit http://epidemiology.mit.edu/pnas 
%      CANCERFIT, by itself, creates a new CANCERFIT or raises the existing
%      singleton*.
%
%      H = CANCERFIT returns the handle to a new CANCERFIT or the handle to
%      the existing singleton*.
%
%      CANCERFIT('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in CANCERFIT.M with the given input arguments.
%
%      CANCERFIT('Property','Value',...) creates a new CANCERFIT or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before CancerFit_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to CancerFit_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES



% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @CancerFit_OpeningFcn, ...
                   'gui_OutputFcn',  @CancerFit_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before CancerFit is made visible.
function CancerFit_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to CancerFit (see VARARGIN)

% Choose default command line output for CancerFit
handles.output = hObject;

% Initialize variables
set(handles.text_mu,'String','m','FontName','symbol');
handles.num_fits = 100;
handles.curr_row = 1;
handles.fit_id = 0;
handles.top_fits = zeros(10,1000,8);
handles.top_fit_vals = zeros(10,1000,51);
handles.past_INC = zeros(10,25);
handles.nstrata = 10;
handles.startstrata = 1;
handles.endstrata = 7.5;

warning off

addpath src/
addpath util/

% Update handles structure
guidata(hObject, handles);



% --- Outputs from this function are returned to the command line.
function varargout = CancerFit_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in openOBS.
function openOBS_Callback(hObject, eventdata, handles)
% Implementation of Opening OBS*(h,t) File
% hObject    handle to openOBS (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

cla(handles.axes1);
% Open dialog box
[file_name, mach_path] = uigetfile( ...
    {'*.txt', 'All TEXT-Files (*.txt)'; ...
       '*.MAT', 'All MAT-Files (*.MAT)'; ... 
       '*.xls', 'All MS Excel 97-2003 Files (*.xls)'; ... 
       '*.xlsx', 'All MS Excel 2007 Files (*.xlsx)'; ... 
       '*.*','All Files (*.*)'}, ...
    'Select Mortality File', [pwd '/Mortality Files_Editable/Cancer of the lower GI Tract_EAM.txt']);
 
% If "Cancel" is selected then return
if isequal([file_name,mach_path],[0,0])
    return
% Otherwise construct the fullfilename and Check and load the file
else
    File = fullfile(mach_path,file_name);
end

% Store file information into handles
handles.mp=mach_path;
handles.obs_fn=file_name;
guidata(hObject,handles);

% Get file extension
length_fn=length(file_name);
st_pt=length_fn+1-4;
file_ext=file_name(st_pt:length_fn);

% Get complete path location
pathloc=[mach_path file_name];

% if the file is a text file
if file_ext == '.txt' 
    %Open it and read text
    fid = fopen (pathloc,'r');
    C = textscan(fid,'%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f');
    fclose(fid);
    if(isnan(C{1}))
        errordlg('You must choose an appropriate OBS* file with numeric values','Bad Input','modal')
    	return;
    end
    
    % Prevent user from working with SUR before user chooses birth cohort h
    set(handles.pushbutton_SUR,'Enable','off');
    set(handles.checkbox_SUR0,'Value',0);
    set(handles.checkbox_SUR0,'Enable','off');
    
    % Create OBS*(h,t) array
    all_obs = zeros(size(C{1},1),26);
    % Fill in OBS* array using text file content
    for i = 1:size(C{1},1)
        array_len = 25;
        for j = 1:26,
            if isnan(C{j}(i))
                array_len = j-2;
                break;
            end
        end
        
        all_obs(i,1) = C{1}(i);
        for k = 1:array_len
            all_obs(i,26-array_len+k) = C{k+1}(i);
        end
    end
    
    % reads in the data and saves it as a handle structure
    handles.all_obs = all_obs;  
    handles.num_cohorts = size(all_obs,1);
    guidata(hObject, handles);
    
    % Plot all decades in semilog plot
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    axes(handles.axes1);        
    
    for i = 1:handles.num_cohorts
        tmp_h= semilogy(x_data,all_obs(i,2:end),'k');
        set(tmp_h,'LineStyle',data_points{mod(i-1,size(data_points,2))+1}(2:end));
        set(tmp_h,'Marker',data_points{mod(i-1,size(data_points,2))+1}(1),'MarkerSize',3);
        hold on
    end
    lgd = legend(num2str(all_obs(:,1)));
    set(lgd,'Location','EastOutside')
    set(lgd,'FontSize',8)
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    for i = 1:handles.num_cohorts        
        ymax= max(max(all_obs(i,2:end)),ymax);
        ymin= min(min(all_obs(i,2:end)),ymin);
    end
    ylim([max(ymin/10,1E-4) ymax*10])
    grid on
    set(gca,'XMinorGrid','off','YMinorGrid','on','XMinorTick','off')
    axis square
    xlabel('Age (t)');
    ylabel('OBS*(t) per 100,000');

    % Create title for OBS*(h,t) plot
    if(strcmp(handles.race,'EAM'))
        title('OBS*(h,t) for European American Males (EAM)')
    elseif(strcmp(handles.race,'EAF'))
        title('OBS*(h,t) for European American Females (EAF)')
    elseif(strcmp(handles.race,'NEAM'))
        title('OBS*(h,t) for Non-European American Males (NEAM)')
    elseif(strcmp(handles.race,'NEAF'))
        title('OBS*(h,t) for Non-European American Females (NEAF)')
    end        
    
    % Enable cohort and plot buttons
    set(handles.popupmenu_cohort,'String',num2str(handles.all_obs(:,1)))
    set(handles.pushbutton_linlin,'Enable','on')
    set(handles.pushbutton_loglin,'Enable','on')
    set(handles.pushbutton_loglog,'Enable','on')
    
    % Re-Enable user from working with SUR before user chooses birth cohort
    set(handles.popupmenu_cohort,'Enable','on');
    
    handles.cohort = handles.all_obs(1,1);
    
    guidata(hObject, handles);

% if the file is an excel file
elseif (file_ext == '.xls')
    [NUMERIC,TXT,RAW]=XLSREAD(pathloc,['Raw Adj (' handles.race ')']);
    [NUMERIC_POP,TXT_POP,RAW_POP]=XLSREAD(pathloc,['Population (' handles.race ')']);

    age_groups = [0,1,2,3,4,7:5:102];

    all_obs = nan(1,26); % TODO: nan or zero?

    first_year = NUMERIC(1,1);            
    first_decade = max(ceil((first_year - 111)/10)*10,1800);
    [num_rows, num_cols] = size(NUMERIC);
    [num_pop_rows, num_pop_cols] = size(NUMERIC_POP);

    decade_id = 1;
    for decade=first_decade:10:2000,
        raw_tot = 0;
        pop_tot = 0;    

        all_obs(decade_id,1) = decade;      

        for i=1:size(age_groups,2)        
            starting_year = decade+age_groups(i);
            if(starting_year >= first_year)
                [row,col] = find(NUMERIC(:,1) == starting_year);
                [row_pop,col_pop] = find(NUMERIC_POP(:,1) == starting_year);
                if(i<6)
                    raw_tot = sum(NUMERIC(row:min(row+9,num_rows),2+i),1);
                    if(i == 1)
                        pop_tot = sum(NUMERIC_POP(row_pop:min(row_pop+9,num_pop_rows),2+i),1);
                    else
                        pop_tot = sum(NUMERIC_POP(row_pop:min(row_pop+9,num_pop_rows),4),1)/4;
                    end
                else
                    raw_tot = sum(NUMERIC(row:min(row+9,num_rows),3+i),1);
                    pop_tot = sum(NUMERIC_POP(row_pop:min(row_pop+9,num_pop_rows),i-1),1);
                end
            elseif(starting_year+9 >= first_year)
                [row,col] = find(NUMERIC(:,1) == first_year);
                [row_end,col] = find(NUMERIC(:,1) == starting_year+9);

                [row_pop,col_pop] = find(NUMERIC_POP(:,1) == first_year);
                [row_end_pop,col_pop] = find(NUMERIC_POP(:,1) == starting_year+9);

                if(row_end)
                    if(i<6)
                        raw_tot = sum(NUMERIC(row:row_end,2+i),1);
                        if(i == 1)
                            pop_tot = sum(NUMERIC_POP(row_pop:row_end_pop,2+i),1);
                        else
                            pop_tot = sum(NUMERIC_POP(row_pop:row_end_pop,4),1)/4;
                        end                    
                    else
                        raw_tot = sum(NUMERIC(row:row_end,3+i),1);
                        pop_tot = sum(NUMERIC_POP(row_pop:row_end_pop,i-1),1);
                    end
                else
                    if(i<6)
                        raw_tot = sum(NUMERIC(row:num_rows,2+i),1);
                        if(i == 1)
                            pop_tot = sum(NUMERIC_POP(row_pop:num_pop_rows,2+i),1);
                        else
                            pop_tot = sum(NUMERIC_POP(row_pop:num_pop_rows,4),1)/4;
                        end                    
                    else
                        raw_tot = sum(NUMERIC(row:num_rows,3+i),1);
                        pop_tot = sum(NUMERIC_POP(row_pop:num_pop_rows,i-1),1);
                    end
                end
            end

            if(raw_tot == 0 && pop_tot == 0)
                obs = 0;  % TODO: NaN or 0?     
            else
                obs = raw_tot/pop_tot;
            end

            all_obs(decade_id,i+1) = obs*1E5;        
        end        
        decade_id = decade_id + 1;     
    end

    % reads in the data and saves it as a handle structure
    handles.all_obs = all_obs;  
    handles.num_cohorts = size(all_obs,1);
    guidata(hObject, handles);
    
    % Plot all decades in semilog plot
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    axes(handles.axes1);        
    
    for i = 1:handles.num_cohorts
        tmp_h= semilogy(x_data,all_obs(i,2:end),'k');
        set(tmp_h,'LineStyle',data_points{mod(i-1,size(data_points,2))+1}(2:end));
        set(tmp_h,'Marker',data_points{mod(i-1,size(data_points,2))+1}(1),'MarkerSize',3);
        hold on
    end
    lgd = legend(num2str(all_obs(:,1)));
    set(lgd,'Location','EastOutside')
    set(lgd,'FontSize',6)
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    for i = 1:handles.num_cohorts        
        ymax= max(max(all_obs(i,2:end)),ymax);
        ymin= min(min(all_obs(i,2:end)),ymin);
    end
    ylim([max(ymin/10,1E-4) ymax*10])
    grid on
    set(gca,'XMinorGrid','off','YMinorGrid','on','XMinorTick','off')
    axis square
    xlabel('Age (t)');
    ylabel('OBS*(t) per 100,000');

    % Create title for OBS*(h,t) plot
    if(strcmp(handles.race,'EAM'))
        title('OBS*(h,t) for European American Males (EAM)')
    elseif(strcmp(handles.race,'EAF'))
        title('OBS*(h,t) for European American Females (EAF)')
    elseif(strcmp(handles.race,'NEAM'))
        title('OBS*(h,t) for Non-European American Males (NEAM)')
    elseif(strcmp(handles.race,'NEAF'))
        title('OBS*(h,t) for Non-European American Females (NEAF)')
    end        
    
    % Enable cohort and plot buttons
    set(handles.popupmenu_cohort,'String',num2str(handles.all_obs(:,1)))
    set(handles.pushbutton_linlin,'Enable','on')
    set(handles.pushbutton_loglin,'Enable','on')
    set(handles.pushbutton_loglog,'Enable','on')
    
    % Re-Enable user from working with SUR before user chooses birth cohort
    set(handles.popupmenu_cohort,'Enable','on');
    
    handles.cohort = handles.all_obs(1,1);
    
    guidata(hObject, handles);
    
elseif file_ext == '.MAT' % if the file is a mat file
    % Process MAT file for OBS*(h,t) array
    % Assumes MAT file contains Num cohorts x 26 all_obs array
    
    if(exist('all_obs'))
        errordlg('You must choose an appropriate OBS* file with all_obs variable','Bad Input','modal')
    	return;
    end
    
    % Saves all_obs data from MAT file as a handle structure
    handles.all_obs = all_obs;  
    handles.num_cohorts = size(all_obs,1);
    guidata(hObject, handles);
    
    % Plot all decades in semilog plot
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    axes(handles.axes1);        
    
    for i = 1:handles.num_cohorts
        tmp_h= semilogy(x_data,all_obs(i,2:end),'k');
        set(tmp_h,'LineStyle',data_points{mod(i-1,size(data_points,2))+1}(2:end));
        set(tmp_h,'Marker',data_points{mod(i-1,size(data_points,2))+1}(1),'MarkerSize',3);
        hold on
    end
    lgd = legend(num2str(all_obs(:,1)));
    set(lgd,'Location','EastOutside')
    set(lgd,'FontSize',6)
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    for i = 1:handles.num_cohorts        
        ymax= max(max(all_obs(i,2:end)),ymax);
        ymin= min(min(all_obs(i,2:end)),ymin);
    end
    ylim([max(ymin/10,1E-4) ymax*10])
    grid on
    set(gca,'XMinorGrid','off','YMinorGrid','on','XMinorTick','off')
    axis square
    xlabel('Age (t)');
    ylabel('OBS*(t) per 100,000');

    % Create title for OBS*(h,t) plot
    if(strcmp(handles.race,'EAM'))
        title('OBS*(h,t) for European American Males (EAM)')
    elseif(strcmp(handles.race,'EAF'))
        title('OBS*(h,t) for European American Females (EAF)')
    elseif(strcmp(handles.race,'NEAM'))
        title('OBS*(h,t) for Non-European American Males (NEAM)')
    elseif(strcmp(handles.race,'NEAF'))
        title('OBS*(h,t) for Non-European American Females (NEAF)')
    end        
    
    % Enable cohort and plot buttons
    set(handles.popupmenu_cohort,'String',num2str(handles.all_obs(:,1)))
    set(handles.pushbutton_linlin,'Enable','on')
    set(handles.pushbutton_loglin,'Enable','on')
    set(handles.pushbutton_loglog,'Enable','on')
    
    handles.cohort = handles.all_obs(1,1);
    
    guidata(hObject, handles);
else
    errordlg('You must choose an appropriate OBS* file with numeric values','Bad Input','modal')
    return;
        
end


% --- Executes on selection change in popupmenu_cohort.
function popupmenu_cohort_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_cohort (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
val = get(hObject,'Value');
string_list = get(hObject,'String');
selected_string = string_list(val,:); % Convert from cell array
                                    % to string
handles.cohort = str2double(selected_string);
guidata(hObject, handles);

% Plot chosen cohort in semilog plot
data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
axes(handles.axes1);
cla
tmp_h= semilogy(x_data,handles.all_obs(val,2:end),'k');
set(tmp_h,'LineStyle',data_points{mod(val-1,size(data_points,2))+1}(2:end));
set(tmp_h,'Marker',data_points{mod(val-1,size(data_points,2))+1}(1),'MarkerSize',3);

% Set plot limits
xlim([0 110])
ymin = 1E100;
ymax = 1E-100;
ymax= max(max(handles.all_obs(val,2:end)),ymax);
ymin= min(min(handles.all_obs(val,2:end)),ymin);

ylim([max(ymin/10,1E-4) ymax*10])
grid on
axis square
xlabel('Age (t)');
ylabel('OBS*(t) per 100,000');

%Set plot title
if(strcmp(handles.race,'EAM'))
    title(strcat('OBS*(h=',num2str(handles.cohort),',t) for European American Males (EAM)'))
elseif(strcmp(handles.race,'EAF'))
    title(strcat('OBS*(h=',num2str(handles.cohort),',t) for European American Females (EAF)'))
elseif(strcmp(handles.race,'NEAM'))
    title(strcat('OBS*(h=',num2str(handles.cohort),',t) for Non-European American Males (NEAM)'))
elseif(strcmp(handles.race,'NEAF'))
    title(strcat('OBS*(h=',num2str(handles.cohort),',t) for Non-European American Females (NEAF)'))
end        

handles.obs = handles.all_obs(val,2:end);

%Enable SUR input from user since cohort has been chosen
set(handles.pushbutton_SUR,'Enable','on')
set(handles.checkbox_SUR0,'Value',0);
set(handles.checkbox_SUR0,'Enable','on');

guidata(hObject, handles);



% --- Executes during object creation, after setting all properties.
function popupmenu_cohort_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_cohort (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in radiobutton_EAM.
function radiobutton_EAM_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton_EAM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Radio button is selected, take appropriate action
    handles.race = 'EAM';
    guidata(hObject,handles);
else
	% Radio button is not selected, take appropriate action
end


% --- Executes during object creation, after setting all properties.
function radiobutton_EAM_CreateFcn(hObject, eventdata, handles)
% hObject    handle to radiobutton_EAM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
handles.race = 'EAM';
guidata(hObject,handles);

% --- Executes on button press in radiobutton_EAF.
function radiobutton_EAF_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton_EAF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Radio button is selected, take appropriate action
    handles.race = 'EAF';
    guidata(hObject,handles);
else
	% Radio button is not selected, take appropriate action
end

% --- Executes on button press in radiobutton_NEAM.
function radiobutton_NEAM_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton_NEAM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Radio button is selected, take appropriate action
    handles.race = 'NEAM';
    guidata(hObject,handles);
else
	% Radio button is not selected, take appropriate action
end

% --- Executes on button press in radiobutton_NEAF.
function radiobutton_NEAF_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton_NEAF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Radio button is selected, take appropriate action
    handles.race = 'NEAF';
    guidata(hObject,handles);
else
	% Radio button is not selected, take appropriate action
end


% --- Executes on button press in pushbutton_SUR.
function pushbutton_SUR_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_SUR (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[file_name, mach_path] = uigetfile( ...
    {'*.txt', 'All TEXT-Files (*.txt)'; ...
       '*.MAT', 'All MAT-Files (*.MAT)'; ... 
       '*.*','All Files (*.*)'}, ...
    'Select File');
 
% If "Cancel" is selected then return
if isequal([file_name,mach_path],[0,0])
    return
% Otherwise construct the fullfilename and Check and load the file
else
    File = fullfile(mach_path,file_name);
end

% Set SUR file name in handles
handles.mp=mach_path;
handles.sur_fn=file_name;

% Get file extension and full file path
guidata(hObject,handles);
file_name=handles.sur_fn;
length_fn=length(file_name);
st_pt=length_fn+1-4;
file_ext=file_name(st_pt:length_fn);
mpath=mach_path;
pathloc=[mpath file_name];

if file_ext == '.txt' % if the file is a text file
    fid = fopen (file_name,'r');
    C = textscan(fid,'%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f');
    fclose(fid);
    if(isnan(C{1}))
        errordlg('You must choose an appropriate SUR file with numeric values','Bad Input','modal')
        return;
    end
    all_sur = zeros(size(C{1},1),26);
    for i = 1:size(C{1},1)
        array_len = 25;
        for j = 1:26,
            if isnan(C{j}(i))
                array_len = j-2;
                break;
            end
        end
        
        all_sur(i,1) = C{1}(i);
        for k = 1:array_len
            all_sur(i,26-array_len+k) = C{k+1}(i);
        end
    end
    
    % reads in the data and saves it as a handle structure
    handles.all_sur = all_sur;  
    guidata(hObject, handles);
    
    % Plot all SUR in semilog plot
    tmp_fig_h = figure;
    hold on;
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    
    
    for i = 1:size(C{1},1)
        tmp_h= plot(x_data,all_sur(i,2:end),'k');
        set(tmp_h,'LineStyle',data_points{mod(i-1,size(data_points,2))+1}(2:end));
        set(tmp_h,'Marker',data_points{mod(i-1,size(data_points,2))+1}(1),'MarkerSize',3);
        hold on
    end
    lgd = legend(num2str(all_sur(:,1)));
    set(lgd,'Location','EastOutside')
    set(lgd,'FontSize',6)
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    for i = 1:size(C{1},1)        
        ymax= max(max(all_sur(i,2:end)),ymax);
        ymin= min(min(all_sur(i,2:end)),ymin);
    end
    ylim([0 ymax*1.5])
    grid on
    set(gca,'XMinorGrid','off','YMinorGrid','on','XMinorTick','off')
    axis square
    xlabel('Age (t)');
    ylabel('SUR(t) Fraction');

    % Create title for SUR(h,t) plot
    if(strcmp(handles.race,'EAM'))
        title('SUR(h,t) for European American Males (EAM)')
    elseif(strcmp(handles.race,'EAF'))
        title('SUR(h,t) for European American Females (EAF)')
    elseif(strcmp(handles.race,'NEAM'))
        title('SUR(h,t) for Non-European American Males (NEAM)')
    elseif(strcmp(handles.race,'NEAF'))
        title('SUR(h,t) for Non-European American Females (NEAF)')
    end        
    

    
    matching_cohort = -1;
    for i = 1:size(handles.all_sur,1)
        if(handles.all_sur(i,1) == handles.cohort)
            matching_cohort = i;            
            break;
        end
    end
    if(matching_cohort == -1)
        handles.sur = zeros(1,25);
    else
        handles.sur = handles.all_sur(matching_cohort,2:end);
    end
    guidata(hObject, handles);
    
    % Calculate INC as INC = OBS*(h,t) / (1-SUR(h,t))
    %    and store it in handles
    INC = zeros(1,25);
    for i = 1:25
        INC(1,i) = handles.obs(1,i) /(1-handles.sur(1,i));
    end

    handles.INC = INC;
    
    guidata(hObject, handles);
    
    % Plot cohort INC in semilog plot
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    axes(handles.axes1);    
    
    cla
    tmp_h= semilogy(x_data,handles.INC,'k');
    set(tmp_h,'LineStyle',data_points{1}(2:end));
    set(tmp_h,'Marker',data_points{1}(1));
    
    % Set plot limits and title
    legend off
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    ymax= max(max(handles.INC,ymax));
    ymin= min(min(handles.INC,ymin));

    ylim([max(ymin/10,1E-4) ymax*10])
    grid on
    axis square
    xlabel('Age (t)');
    ylabel('INC(t) per 100,000');
    if(strcmp(handles.race,'EAM'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for European American Males (EAM)'))
    elseif(strcmp(handles.race,'EAF'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for European American Females (EAF)'))
    elseif(strcmp(handles.race,'NEAM'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for Non-European American Males (NEAM)'))
    elseif(strcmp(handles.race,'NEAF'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for Non-European American Females (NEAF)'))
    end            

    % Enable RUN button since all necessary parameters are entered
    set(handles.pushbutton_RUN,'Enable','on');

    guidata(hObject, handles);
else
    errordlg('You must choose an appropriate SUR file with numeric values','Bad Input','modal')
    return;
end

% --- Executes on button press in checkbox_SUR0.
function checkbox_SUR0_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_SUR0 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

if (get(hObject,'Value') == get(hObject,'Max'))
    % Checkbox is checked-take approriate action
    handles.all_sur = 0;  
    handles.sur = 0;
    guidata(hObject, handles);

    INC = zeros(1,25);
    
    % INC(h,t) = OBS*(h,t) if SUR(h,t) = 0
    INC = handles.obs;
    handles.INC = INC;    
    guidata(hObject, handles);

    % Plot cohort INC in semilog plot
    data_points = {'s-','^-','o-','h-','d-','D-','+--','x--','p--','s--','s--','^--','o--','h--','d--','D--','+--','x--','s-.','^-.','o-.','h-.','d-.','D-.'};
    x_data = [0.5,1,2,3,4,7.5,12.5,17.5,22.5,27.5,32.5,37.5,42.5,47.5,52.5,57.5,62.5,67.5,72.5,77.5,82.5,87.5,92.5,97.5,102.5];
    axes(handles.axes1);    

    cla
    tmp_h= semilogy(x_data,handles.INC,'k');
    set(tmp_h,'LineStyle',data_points{1}(2:end));
    set(tmp_h,'Marker',data_points{1}(1),'MarkerSize',3);

    % Set plot limits, labels and title
    legend off
    xlim([0 110])
    ymin = 1E100;
    ymax = 1E-100;
    ymax= max(max(handles.INC,ymax));
    ymin= min(min(handles.INC,ymin));

    ylim([max(ymin/10,1E-4) ymax*10])
    grid on
    axis square
    xlabel('Age (t)');
    ylabel('INC(t) per 100,000');
    if(strcmp(handles.race,'EAM'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for European American Males (EAM)'))
    elseif(strcmp(handles.race,'EAF'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for European American Females (EAF)'))
    elseif(strcmp(handles.race,'NEAM'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for Non-European American Males (NEAM)'))
    elseif(strcmp(handles.race,'NEAF'))
        title(strcat('INC(h=',num2str(handles.cohort),',t) for Non-European American Females (NEAF)'))
    end            

    set(handles.pushbutton_SUR,'Enable','off');
    set(handles.pushbutton_RUN,'Enable','on');

    guidata(hObject, handles);
    
else
   % Checkbox is not checked-take approriate action
   set(handles.pushbutton_SUR,'Enable','on');
   guidata(hObject, handles);
end

function edit_amax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_amax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
amax = str2double(get(hObject,'string'));
if isnan(amax)
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.amax = amax;
guidata(hObject, handles);


% --- Executes during object creation, after setting all propertie s.
function edit_amax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_amax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

handles.amax = 23.25;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_m_Callback(hObject, eventdata, handles)
% hObject    handle to edit_m (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
m = str2double(get(hObject,'string'));
if isnan(m) || (floor(m) - m ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.m = m;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_m_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_m (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.m = 1;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_n_Callback(hObject, eventdata, handles)
% hObject    handle to edit_n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
n = str2double(get(hObject,'string'));
if isnan(n) || (floor(n) - n ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.n = n;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_n_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.n = 2;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox_F.
function checkbox_F_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_F (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_nF,'String','1','Enable','Off');
    set(handles.edit_Fend,'String','1','Enable','Off');
    handles.nF = 1;
    handles.Fstart = str2double(get(handles.edit_Fstart,'string'));
    handles.Fend = str2double(get(handles.edit_Fend,'string'));
    guidata(hObject, handles);
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_nF,'String','20','Enable','On');
    set(handles.edit_Fend,'String','1','Enable','On');
    handles.nF = 20;
    handles.Fstart = str2double(get(handles.edit_Fstart,'string'));

    guidata(hObject, handles);    
end


% --- Executes on button press in checkbox_sf.
function checkbox_sf_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_sf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_nsf,'String','1','Enable','Off');
    set(handles.edit_sfend,'String','1','Enable','Off');
    handles.nsf = 1;
    handles.sfstart = str2double(get(handles.edit_sfstart,'string'));
    handles.sfend = str2double(get(handles.edit_sfend,'string'));
    guidata(hObject, handles);
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_nsf,'String','20','Enable','On');
    set(handles.edit_sfend,'String','1','Enable','On');
    handles.nsf = 20;
    handles.sfstart = str2double(get(handles.edit_sfstart,'string'));

    guidata(hObject, handles);    
end


% --- Executes on button press in checkbox_mu.
function checkbox_mu_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_mu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_nmu,'String','1','Enable','Off');
    set(handles.edit_muend,'String','0.3','Enable','Off');
    handles.nmu = 1;
    handles.mustart = str2double(get(handles.edit_mustart,'string'));
    handles.muend = str2double(get(handles.edit_muend,'string'));
    guidata(hObject, handles);
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_nmu,'String','20','Enable','On');
    set(handles.edit_muend,'String','0.3','Enable','On');
    handles.nmu = 20;
    handles.mustart = str2double(get(handles.edit_mustart,'string'));

    guidata(hObject, handles);    
end


% --- Executes on button press in checkbox_Ri.
function checkbox_Ri_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_Ri (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_nRi,'String','1','Enable','Off');
    set(handles.edit_Riend,'String','1E-4','Enable','Off');
    handles.nRi = 1;
    handles.Ristart = str2double(get(handles.edit_Ristart,'string'));
    handles.Riend = str2double(get(handles.edit_Riend,'string'));
    guidata(hObject, handles);
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_nRi,'String','20','Enable','On');
    set(handles.edit_Riend,'String','1E-4','Enable','On');
    handles.nRi = 20;
    handles.Ristart = str2double(get(handles.edit_Ristart,'string'));

    guidata(hObject, handles);    
end


% --- Executes on button press in checkbox_RA.
function checkbox_RA_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_RA (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_nRA,'String','1','Enable','Off');
    set(handles.edit_RAend,'String','1E-4','Enable','Off');
    handles.nRA = 1;
    handles.RAstart = str2double(get(handles.edit_RAstart,'string'));
    handles.RAend = str2double(get(handles.edit_RAend,'string'));
    guidata(hObject, handles);
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_nRA,'String','20','Enable','On');
    set(handles.edit_RAend,'String','1E-4','Enable','On');
    handles.nRA = 20;
    handles.RAstart = str2double(get(handles.edit_RAstart,'string'));

    guidata(hObject, handles);    
end



function edit_nF_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
nF = str2double(get(hObject,'string'));
if isnan(nF) || (floor(nF) - nF ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.nF = nF;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_nF_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.nF = 20;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_Fstart_Callback(hObject, eventdata, handles)
% hObject    handle to edit_Fstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Fstart = str2double(get(hObject,'string'));
if isnan(Fstart) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.Fstart = Fstart;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_Fstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_Fstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.Fstart = 0.01;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_Fend_Callback(hObject, eventdata, handles)
% hObject    handle to edit_Fend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Fend = str2double(get(hObject,'string'));
if isnan(Fend) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.Fend = Fend;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_Fend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_Fend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.Fend = 1.0;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_nsf_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nsf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
nsf = str2double(get(hObject,'string'));
if isnan(nsf) || (floor(nsf) - nsf ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.nsf = nsf;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_nsf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nsf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.nsf = 20;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_sfstart_Callback(hObject, eventdata, handles)
% hObject    handle to edit_sfstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
sfstart = str2double(get(hObject,'string'));
if isnan(sfstart) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.sfstart = sfstart;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_sfstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_sfstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.sfstart = 0.01;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_sfend_Callback(hObject, eventdata, handles)
% hObject    handle to edit_sfend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
sfend = str2double(get(hObject,'string'));
if isnan(sfend) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.sfend = sfend;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_sfend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_sfend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.sfend = 1.0;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_nmu_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nmu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
nmu = str2double(get(hObject,'string'));
if isnan(nmu) || (floor(nmu) - nmu ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.nmu = nmu;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_nmu_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nmu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.nmu = 20;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_mustart_Callback(hObject, eventdata, handles)
% hObject    handle to edit_mustart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
mustart = str2double(get(hObject,'string'));
if isnan(mustart) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.mustart = mustart;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_mustart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_mustart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.mustart = 0.1;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_muend_Callback(hObject, eventdata, handles)
% hObject    handle to edit_muend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
muend = str2double(get(hObject,'string'));
if isnan(muend) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.muend = muend;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_muend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_muend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.muend = 0.3;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_nRi_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nRi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
nRi = str2double(get(hObject,'string'));
if isnan(nRi) || (floor(nRi) - nRi ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.nRi = nRi;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_nRi_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nRi (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.nRi = 20;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_Ristart_Callback(hObject, eventdata, handles)
% hObject    handle to edit_Ristart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Ristart = str2double(get(hObject,'string'));
if isnan(Ristart) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.Ristart = Ristart;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_Ristart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_Ristart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.Ristart = 1E-6;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_Riend_Callback(hObject, eventdata, handles)
% hObject    handle to edit_Riend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Riend = str2double(get(hObject,'string'));
if isnan(Riend) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.Riend = Riend;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_Riend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_Riend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.Riend = 1E-4;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_nRA_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nRA (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
nRA = str2double(get(hObject,'string'));
if isnan(nRA) || (floor(nRA) - nRA ~= 0)
	errordlg('You must enter an integer value','Bad Input','modal')
	return
end
handles.nRA = nRA;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_nRA_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nRA (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.nRA = 20;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_RAstart_Callback(hObject, eventdata, handles)
% hObject    handle to edit_RAstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
RAstart = str2double(get(hObject,'string'));
if isnan(RAstart) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.RAstart = RAstart;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_RAstart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_RAstart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.RAstart = 1E-6;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_RAend_Callback(hObject, eventdata, handles)
% hObject    handle to edit_RAend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
RAend = str2double(get(hObject,'string'));
if isnan(RAend) 
	errordlg('You must enter a numeric value','Bad Input','modal')
	return
end
handles.RAend = RAend;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_RAend_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_RAend (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
handles.RAend = 1E-4;
guidata(hObject, handles);
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton_RUN.
function pushbutton_RUN_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_RUN (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Temporary
if(handles.nmu == 1 && handles.nsf == 1 && handles.nF == 1)
    errordlg('Running fits with all three variables mu, F_prom, and f fixed is currently still under construction. Allow at least one of these variables to vary at least 2 iterations.','Bad Input','modal')
    return;
end

% Obtain CancerFit run parameters
handles.num_fits = min(100,handles.nF*handles.nsf*handles.nmu);
handles.fit_id = handles.fit_id + 1; % Sets global fit id
set(handles.pushbutton_RUN,'Enable','off') % Prevent double clicking
guidata(hObject, handles);

%%%% RUN %%%%
% Pass handles as input to CalculateFits algorithm
handles = CalculateFits(handles);

% Get uitable1 data (all previously run fits)
data = get(handles.uitable1,'Data');

% Add current CancerFit run to uitable1 data 
% Table can support maximum 10 rows
if(handles.curr_row == 11)
    for is = 1:9
        for j = 1:17
            data{is,j} = data{is+1,j}
        end
    end
    handles.curr_row = 10;
    
    % Include all details of run
    data{handles.curr_row,1} = handles.fit_id;
    
    data{handles.curr_row,2} = handles.nF;
    data{handles.curr_row,3} = handles.Fstart;
    data{handles.curr_row,4} = handles.Fend;
    
    data{handles.curr_row,5} = handles.nsf;
    data{handles.curr_row,6} = handles.sfstart;
    data{handles.curr_row,7} = handles.sfend;
    
    data{handles.curr_row,8} = handles.nmu;
    data{handles.curr_row,9} = handles.mustart;
    data{handles.curr_row,10} = handles.muend;
    
    data{handles.curr_row,11} = handles.nRi;
    data{handles.curr_row,12} = handles.Ristart;
    data{handles.curr_row,13} = handles.Riend;
    
    data{handles.curr_row,14} = handles.nRA;
    data{handles.curr_row,15} = handles.RAstart;
    data{handles.curr_row,16} = handles.RAend;
    
    % Time stamp
    data{handles.curr_row,17} = cputime;
    
    handles.curr_row = handles.curr_row+1;
else
    data{handles.curr_row,1} = handles.fit_id;
    
    data{handles.curr_row,2} = handles.nF;
    data{handles.curr_row,3} = handles.Fstart;
    data{handles.curr_row,4} = handles.Fend;
    
    data{handles.curr_row,5} = handles.nsf;
    data{handles.curr_row,6} = handles.sfstart;
    data{handles.curr_row,7} = handles.sfend;
    
    data{handles.curr_row,8} = handles.nmu;
    data{handles.curr_row,9} = handles.mustart;
    data{handles.curr_row,10} = handles.muend;
    
    data{handles.curr_row,11} = handles.nRi;
    data{handles.curr_row,12} = handles.Ristart;
    data{handles.curr_row,13} = handles.Riend;
    
    data{handles.curr_row,14} = handles.nRA;
    data{handles.curr_row,15} = handles.RAstart;
    data{handles.curr_row,16} = handles.RAend;
    
    % Time stamp
    data{handles.curr_row,17} = cputime;   
    
    handles.curr_row = handles.curr_row+1;
end

set(handles.uitable1,'Data',data);

% Reset RUN button
set(handles.pushbutton_RUN,'Enable','on')

handles.selected_row = handles.curr_row-1;
handles.selected_col = 1;
guidata(hObject, handles);

% When user selects row, open Best_Fits to show top num_fits results for
%     selected row
Best_Fits('cancerFit',handles.figure1);

guidata(hObject, handles);




% --- Executes on button press in pushbutton_linlin.
function pushbutton_linlin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_linlin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'XScale','linear','YScale','linear');
if (get(handles.checkbox_manual_limits,'Value') ...
        == get(handles.checkbox_manual_limits,'Max'))
    xmin = str2double(get(handles.edit_xmin,'String'));
    xmax = str2double(get(handles.edit_xmax,'String'));
    ymin = str2double(get(handles.edit_ymin,'String'));
    ymax = str2double(get(handles.edit_ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax*1.5])
else
    ydata = handles.all_obs(2:end,:);
    ymax = max(max(ydata));
    xlim([0 110])
    ylim([0 ymax*1.5])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_loglin.
function pushbutton_loglin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_loglin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'XScale','linear','YScale','log');
if (get(handles.checkbox_manual_limits,'Value') ...
        == get(handles.checkbox_manual_limits,'Max'))
    xmin = str2double(get(handles.edit_xmin,'String'));
    xmax = str2double(get(handles.edit_xmax,'String'));
    ymin = str2double(get(handles.edit_ymin,'String'));
    ymax = str2double(get(handles.edit_ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    ydata = handles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([0 110])
    ylim([max(ymin/10,1E-10) ymax*10])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_loglog.
function pushbutton_loglog_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_loglog (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'YScale','log','XScale','log');
if (get(handles.checkbox_manual_limits,'Value') ...
        == get(handles.checkbox_manual_limits,'Max'))
    xmin = str2double(get(handles.edit_xmin,'String'));
    xmax = str2double(get(handles.edit_xmax,'String'));
    ymin = str2double(get(handles.edit_ymin,'String'));
    ymax = str2double(get(handles.edit_ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    ydata = handles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([1 110])
    ylim([max(ymin/10,1E-10) ymax*10])    
end
guidata(hObject, handles);


function edit_xmin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(hObject,'String'));
xmax = str2double(get(handles.edit_xmax,'String'));
ymin = str2double(get(handles.edit_ymin,'String'));
ymax = str2double(get(handles.edit_ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit_xmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_xmax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_xmin,'String'));
xmax = str2double(get(hObject,'String'));
ymin = str2double(get(handles.edit_ymin,'String'));
ymax = str2double(get(handles.edit_ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_xmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_ymin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_xmin,'String'));
xmax = str2double(get(handles.edit_xmax,'String'));
ymin = str2double(get(hObject,'String'));
ymax = str2double(get(handles.edit_ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_ymin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_ymax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_xmin,'String'));
xmax = str2double(get(handles.edit_xmax,'String'));
ymin = str2double(get(handles.edit_ymin,'String'));
ymax = str2double(get(hObject,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_ymax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox_manual_limits.
function checkbox_manual_limits_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_manual_limits (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_xmin,'String','0','Enable','On');
    set(handles.edit_xmax,'String','110','Enable','On');
    set(handles.edit_ymin,'String','1E-12','Enable','On');
    set(handles.edit_ymax,'String','1E4','Enable','On');
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_xmin,'String','0','Enable','Off');
    set(handles.edit_xmax,'String','110','Enable','Off');
    set(handles.edit_ymin,'String','1E-12','Enable','Off');
    set(handles.edit_ymax,'String','1E4','Enable','Off');
end


% --- Executes during object creation, after setting all properties.
function pushbutton_linlin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to pushbutton_linlin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes when selected cell(s) is changed in uitable1.
function uitable1_CellSelectionCallback(hObject, eventdata, handles)
% hObject    handle to uitable1 (see GCBO)
% eventdata  structure with the following fields (see UITABLE)
%	Indices: row and column indices of the cell(s) currently selecteds
% handles    structure with handles and user data (see GUIDATA)
if(size(eventdata.Indices))
    row = eventdata.Indices(1);
    col = eventdata.Indices(2);
else
    row = 1; 
    col = 1;
end
handles.selected_row = row;
handles.selected_col = col;
guidata(hObject, handles);

% When user selects row, open Best_Fits to show top num_fits results for
%     selected row
Best_Fits('cancerFit',handles.figure1);


% --------------------------------------------------------------------
function file_Callback(hObject, eventdata, handles)
% hObject    handle to file (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function open_Callback(hObject, eventdata, handles)
% hObject    handle to open (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[file_name, mach_path] = uigetfile( ...
    {'*.txt', 'All TEXT-Files (*.txt)'; ...
       '*.MAT', 'All MAT-Files (*.MAT)'; ... 
       '*.*','All Files (*.*)'}, ...
    'Select File');
 
% If "Cancel" is selected then return
if isequal([file_name,mach_path],[0,0])
    return
% Otherwise construct the fullfilename and Check and load the file
else
    File = fullfile(mach_path,file_name);
end

% restore(handle)
hgload(File)

guidata(hObject, handles);

% --------------------------------------------------------------------
function save_Callback(hObject, eventdata, handles)
% hObject    handle to save (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[filename, pathname] = uiputfile(...
 {'*.m';'*.mdl';'*.mat';'*.*'},...
 'Save as');
% If "Cancel" is selected then return
if isequal([filename,pathname],[0,0])
    return
% Otherwise construct the fullfilename and Check and load the file
else
    File = fullfile(pathname,filename);
end 
% eval(['hgsave('' File ' handles']);
h = gcf;
hgsave(h,File);


% --- Executes on button press in back_button.
function back_button_Callback(hObject, eventdata, handles)
% hObject    handle to back_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% A temp solution for now as no TAB feature is easily 
%    available on MATLAB GUIDE
set(handles.enter_data,'Visible','off');
set(handles.enter_race,'Visible','on');
set(handles.panel_openOBS,'Visible','on');
set(handles.panel_cohort,'Visible','on');
set(handles.panel_SUR,'Visible','on');

set(handles.back_button,'Enable','off');
set(handles.next_button,'Enable','on');

guidata(hObject, handles);

% --- Executes on button press in next_button.
function next_button_Callback(hObject, eventdata, handles)
% hObject    handle to next_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% A temp solution for now as no TAB feature is easily 
%    available on MATLAB GUIDE
set(handles.enter_data,'Visible','on');
set(handles.enter_race,'Visible','off');
set(handles.panel_openOBS,'Visible','off');
set(handles.panel_cohort,'Visible','off');
set(handles.panel_SUR,'Visible','off');

set(handles.back_button,'Enable','on');
set(handles.next_button,'Enable','off');
guidata(hObject, handles);



function edit_endstrata_Callback(hObject, eventdata, handles)
% hObject    handle to edit_endstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_endstrata as text
%        str2double(get(hObject,'String')) returns contents of edit_endstrata as a double
endstrata = str2double(get(handles.edit_endstrata,'String'));
handles.endstrata = endstrata;
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit_endstrata_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_endstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_startstrata_Callback(hObject, eventdata, handles)
% hObject    handle to edit_startstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_startstrata as text
%        str2double(get(hObject,'String')) returns contents of edit_startstrata as a double
startstrata = str2double(get(handles.edit_startstrata,'String'));
handles.startstrata = startstrata;
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit_startstrata_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_startstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_nstrata_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_nstrata as text
%        str2double(get(hObject,'String')) returns contents of edit_nstrata as a double
nstrata = str2double(get(handles.edit_nstrata,'String'));
handles.nstrata = nstrata;
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit_nstrata_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nstrata (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
