%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CancerFit
% 
% Reference: Fetal/Juvenile Tumor Initiation (2010)
% Authors: Kini, L.G., Herrero-Jimenez P., Guitterez Jr E., Hensle, D.,
%    Kogel J., Kusko R., Rexer, K., Kurzweil, R., Gostjeva, E., 
%    Morgenthaler, S., and Thilly WG.
% Contact: Lohith Kini <lkini (AT) mit DOT edu>
% Version: 5.0
% Last modified: March 22, 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function varargout = Best_Fits(varargin)
% BEST_FITS GUI allows users to explore the best fits from CancerFit. Each
%     top fit is accompanied by respective plots in g and t .
%      BEST_FITS, by itself, creates a new BEST_FITS or raises the existing
%      singleton*.
%
%      H = BEST_FITS returns the handle to a new BEST_FITS or the handle to
%      the existing singleton*.
%
%      BEST_FITS('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in BEST_FITS.M with the given input arguments.
%
%      BEST_FITS('Property','Value',...) creates a new BEST_FITS or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Best_Fits_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Best_Fits_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Best_Fits_OpeningFcn, ...
                   'gui_OutputFcn',  @Best_Fits_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Best_Fits is made visible.
function Best_Fits_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Best_Fits (see VARARGIN)

handles.output = hObject;

% Check to see the cancerFit gui is passed in
dontOpen = false;
mainGuiInput = find(strcmp(varargin, 'cancerFit'));
if (isempty(mainGuiInput)) || (length(varargin) <= mainGuiInput) || (~ishandle(varargin{mainGuiInput+1}))
    dontOpen = true;
else
    % Remember the handle, and adjust our position
    handles.cancerFit = varargin{mainGuiInput+1};
    
    % Set the initial text by opening best_fits from CancerFit instance
    mainHandles = guidata(handles.cancerFit);
    handles.mainHandles = mainHandles;
    best_fits = squeeze(mainHandles.top_fits(mainHandles.selected_row,1:mainHandles.num_fits,:));
    
    Ri_deciles = [mainHandles.startstrata:(mainHandles.endstrata-1)/(mainHandles.nstrata-1):mainHandles.endstrata];
    RA_deciles = [mainHandles.startstrata:(mainHandles.endstrata-1)/(mainHandles.nstrata-1):mainHandles.endstrata];
    Ri_deciles_avg = mean(Ri_deciles);
    RA_deciles_avg = mean(RA_deciles);
    Ri_deciles = Ri_deciles/Ri_deciles_avg;
    RA_deciles = RA_deciles/RA_deciles_avg;

    
    for i = 1:mainHandles.num_fits;
    
       intF = fix(best_fits(i,2));
        fracF = best_fits(i,2) - fix(best_fits(i,2));
        
        intf = fix(best_fits(i,3));
        fracf = best_fits(i,3) - fix(best_fits(i,3));
        

        data{i,1} = num2str(best_fits(i,1),2); % Fit error
        data{i,2} = num2str(mainHandles.amax,'%.2f'); % a_max
        data{i,3} = num2str(best_fits(i,8),'%i'); %n
        data{i,4} = num2str(best_fits(i,7),'%i'); %m
        
        if fracF == 0
        data{i,5} = num2str(best_fits(i,2),'%i'); %F_promotion
        else data{i,5} = num2str(best_fits(i,2),'%.2f');
        end
        
        if fracf == 0;
        data{i,6} = num2str(best_fits(i,3),'%i'); %f
        else data{i,6} = num2str(best_fits(i,3),'%.2f'); end
        
        data{i,7} = num2str(best_fits(i,4),'%.3f'); %mu
        data{i,8} = num2str(best_fits(i,5),'%10.2e\n'); %R_initiation (Ri)
        data{i,9} = num2str(best_fits(i,6),'%10.2e\n');%R_promotion (RA)
        
        
        % Calculate F_init as F_init = 1 - exp ( - sum_0^a_max n * (Ri)^n * a^(n-1) *
        % 2^a )
        Expected_sum = 0;
        Expected_sum2 = 0;
        size(Ri_deciles,2)
        Finit_sum = 0;
            for Ri_deciles_iter = 1:size(Ri_deciles,2)
                for a = 0:1:floor(mainHandles.amax)
            
                Expected_sum = Expected_sum + mainHandles.n*(best_fits(i,5)*Ri_deciles(Ri_deciles_iter))^mainHandles.n*a^(mainHandles.n-1)*2^a;
              
            end
            
           Expected_sum2 = Expected_sum2 + mainHandles.n*best_fits(i,5)^mainHandles.n*a^(mainHandles.n-1)*2^a;
       Finit = 1-exp(-Expected_sum);
       Expected_sum = 0;
       Finit_sum = Finit_sum + Finit;
        end
        Finit_sum = Finit_sum/mainHandles.nstrata;
        
        CAL = squeeze(mainHandles.top_fit_vals(mainHandles.selected_row,i,:));
        
        % Integrate CAL(h,g) over g = 0 .. 50 to compute area
        CAL_area = 0;
        for g = 0:1:50
            CAL_area = CAL_area + CAL(g+1);
        end
        data{i,10} = num2str(Finit_sum,'%.2f');
        data{i,11} = num2str(CAL_area,'%.2f');
      
        
    end   
    
    set(handles.uitable1, 'Data', data);
    
    % Position to be relative to parent:
    parentPosition = getpixelposition(handles.cancerFit);
    currentPosition = get(hObject, 'Position');  
    % Set x to be directly in the middle, and y so that their tops align.
    newX = parentPosition(1) + (parentPosition(3)/2 - currentPosition(3)/2);
    newY = parentPosition(2) + (parentPosition(4)/2 - currentPosition(4)/2);
    %newY = parentPosition(2) + (parentPosition(4) - currentPosition(4));
    newW = currentPosition(3);
    newH = currentPosition(4);
    
    set(hObject, 'Position', [newX, newY, newW, newH]);
end

% Update handles structure
guidata(hObject, handles);

if dontOpen
   disp('-----------------------------------------------------');
   disp('Improper input arguments. Pass a property value pair') 
   disp('whose name is "cancerFit" and value is the handle')
   disp('to the CancerFit figure, e.g:');
   disp('   x = CancerFit()');
   disp('   Best_Fits(''cancerFit'', x)');
   disp('-----------------------------------------------------');
end


% --- Outputs from this function are returned to the command line.
function varargout = Best_Fits_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes when selected cell(s) is changed in uitable1.
function uitable1_CellSelectionCallback(hObject, eventdata, handles)
% hObject    handle to uitable1 (see GCBO)
% eventdata  structure with the following fields (see UITABLE)
%	Indices: row and column indices of the cell(s) currently selecteds
% handles    structure with handles and user data (see GUIDATA)
set(handles.pushbutton_1linlin,'Enable','on');
set(handles.pushbutton_1loglin,'Enable','on');
set(handles.pushbutton_1loglog,'Enable','on');
set(handles.pushbutton_2linlin,'Enable','on');
set(handles.pushbutton_2loglin,'Enable','on');
set(handles.pushbutton_2loglog,'Enable','on');

if(size(eventdata.Indices))
    row = eventdata.Indices(1);
else
    row = -1;
end
    
if(row ~= -1)
    % Plot INC(h,t) with CAL(h,t) as well as INC(h,g) with CAL(h,g)
    mainHandles = handles.mainHandles;
    best_fits = squeeze(mainHandles.top_fits(mainHandles.selected_row,1:mainHandles.num_fits,:));
    i = row;

    CAL = squeeze(mainHandles.top_fit_vals(mainHandles.selected_row,i,:));

    axes(handles.axes1)
    cla
    age_x = [17.5:5:102.5]; 
    age_x_m = [17.5-19:5:102.5-19];
    age_g = age_x_m*best_fits(i,4)+mainHandles.amax;
    % In t domain, INC(h,t) = INC(h,g) / mu because g = amax + mu*(t-17.5)
     semilogy(age_g,mainHandles.past_INC(mainHandles.selected_row,8:end)/best_fits(i,4),'k-o','MarkerEdgeColor','b')
     hold on
    semilogy(0:1:50,CAL*1E5,'k-x','MarkerEdgeColor','r')
%     xlim([0 48])
    grid on
    xlabel('Stem Cell doublings g');
    ylabel('CAL(g) per 100,000');
    title(strcat('CAL(g) and INC(g) for F=',num2str(best_fits(i,2),2),', f=',num2str(best_fits(i,3),2),', mu=',num2str(best_fits(i,4),2),', R_{init}=',num2str(best_fits(i,5),2),', R_{prom}=',num2str(best_fits(i,6),2)));

    axes(handles.axes2)
    cla
    age_x = [17.5:5:102.5];
     semilogy(age_x,mainHandles.past_INC(mainHandles.selected_row,8:end),'k-o','MarkerEdgeColor','b')
     hold on
     age_cal = ([0:1:50]-mainHandles.amax)/best_fits(i,4)+19;
    semilogy(age_cal,CAL*best_fits(i,4)*1E5,'k-x','MarkerEdgeColor','r')
%     xlim([0 120])
    grid on
    xlabel('Age t');
    ylabel('CAL(t) per 100,000');
    title(strcat('CAL(t) and INC(t) for F=',num2str(best_fits(i,2),2),', f=',num2str(best_fits(i,3),2),', mu=',num2str(best_fits(i,4),2),', R_{init}=',num2str(best_fits(i,5)),', R_{prom}=',num2str(best_fits(i,6),2)));

    axes(handles.axes2);
set(gca,'XScale','linear','YScale','log');
mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([0 110])
    ylim([max(ymin/10,1E-10) ymax*10])
    
    
axes(handles.axes1);
set(gca,'Xscale','linear','Yscale','log');
mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([0 50])
    ylim([max(ymin/10,1E-10) ymax*10])
    
    
else
    axes(handles.axes1)
    cla
    axes(handles.axes2)
    cla
end

lgd2 = legend('INC(h,g)','CAL(h,g)','Location','EastOutside');
lgd3 = legend(handles.axes2,'INC(h,t)','CAL(h,t)','Location','EastOutside');
% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in pushbutton_2linlin.
function pushbutton_2linlin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_2linlin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
set(gca,'XScale','linear','YScale','linear');
if (get(handles.checkbox_2manual_limits,'Value') ...
        == get(handles.checkbox_2manual_limits,'Max'))
    xmin = str2double(get(handles.edit_2xmin,'String'));
    xmax = str2double(get(handles.edit_2xmax,'String'));
    ymin = str2double(get(handles.edit_2ymin,'String'));
    ymax = str2double(get(handles.edit_2ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax*1.5])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    xlim([0 110])
    ylim([0 ymax*1.5])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_2loglin.
function pushbutton_2loglin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_2loglin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
set(gca,'XScale','linear','YScale','log');
if (get(handles.checkbox_2manual_limits,'Value') ...
        == get(handles.checkbox_2manual_limits,'Max'))
    xmin = str2double(get(handles.edit_2xmin,'String'));
    xmax = str2double(get(handles.edit_2xmax,'String'));
    ymin = str2double(get(handles.edit_2ymin,'String'));
    ymax = str2double(get(handles.edit_2ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([0 110])
    ylim([max(ymin/10,1E-10) ymax*10])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_2loglog.
function pushbutton_2loglog_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_2loglog (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
set(gca,'YScale','log','XScale','log');
if (get(handles.checkbox_2manual_limits,'Value') ...
        == get(handles.checkbox_2manual_limits,'Max'))
    xmin = str2double(get(handles.edit_2xmin,'String'));
    xmax = str2double(get(handles.edit_2xmax,'String'));
    ymin = str2double(get(handles.edit_2ymin,'String'));
    ymax = str2double(get(handles.edit_2ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([1 110])
    ylim([max(ymin/10,1E-10) ymax*10])    
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton14.
function pushbutton14_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in pushbutton15.
function pushbutton15_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)



function edit_2xmin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_2xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
xmin = str2double(get(hObject,'String'));
xmax = str2double(get(handles.edit_2xmax,'String'));
ymin = str2double(get(handles.edit_2ymin,'String'));
ymax = str2double(get(handles.edit_2ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_2xmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_2xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_2xmax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_2xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
xmin = str2double(get(handles.edit_2xmin,'String'));
xmax = str2double(get(hObject,'String'));
ymin = str2double(get(handles.edit_2ymin,'String'));
ymax = str2double(get(handles.edit_2ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_2xmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_2xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_2ymin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_2ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
xmin = str2double(get(handles.edit_2xmin,'String'));
xmax = str2double(get(handles.edit_2xmax,'String'));
ymin = str2double(get(hObject,'String'));
ymax = str2double(get(handles.edit_2ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_2ymin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_2ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_2ymax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_2ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes2);
xmin = str2double(get(handles.edit_2xmin,'String'));
xmax = str2double(get(handles.edit_2xmax,'String'));
ymin = str2double(get(handles.edit_2ymin,'String'));
ymax = str2double(get(hObject,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_2ymax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_2ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox_2manual_limits.
function checkbox_2manual_limits_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_2manual_limits (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_2xmin,'String','0','Enable','On');
    set(handles.edit_2xmax,'String','110','Enable','On');
    set(handles.edit_2ymin,'String','1E-12','Enable','On');
    set(handles.edit_2ymax,'String','1E4','Enable','On');
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_2xmin,'String','0','Enable','Off');
    set(handles.edit_2xmax,'String','110','Enable','Off');
    set(handles.edit_2ymin,'String','1E-12','Enable','Off');
    set(handles.edit_2ymax,'String','1E4','Enable','Off');
end


% --- Executes on button press in pushbutton_1linlin.
function pushbutton_1linlin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_1linlin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'XScale','linear','YScale','linear');
if (get(handles.checkbox_1manual_limits,'Value') ...
        == get(handles.checkbox_1manual_limits,'Max'))
    xmin = str2double(get(handles.edit_1xmin,'String'));
    xmax = str2double(get(handles.edit_1xmax,'String'));
    ymin = str2double(get(handles.edit_1ymin,'String'));
    ymax = str2double(get(handles.edit_1ymax,'String'));
    xlim([xmin xmax])
    ylim([0 ymax*1.5])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    xlim([0 50])
    ylim([0 ymax*4])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_1loglin.
function pushbutton_1loglin_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_1loglin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'XScale','linear','YScale','log');
if (get(handles.checkbox_1manual_limits,'Value') ...
        == get(handles.checkbox_1manual_limits,'Max'))
    xmin = str2double(get(handles.edit_1xmin,'String'));
    xmax = str2double(get(handles.edit_1xmax,'String'));
    ymin = str2double(get(handles.edit_1ymin,'String'));
    ymax = str2double(get(handles.edit_1ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([0 50])
    ylim([max(ymin/10,1E-10) ymax*10])
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton_1loglog.
function pushbutton_1loglog_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_1loglog (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
set(gca,'YScale','log','XScale','log');
if (get(handles.checkbox_1manual_limits,'Value') ...
        == get(handles.checkbox_1manual_limits,'Max'))
    xmin = str2double(get(handles.edit_1xmin,'String'));
    xmax = str2double(get(handles.edit_1xmax,'String'));
    ymin = str2double(get(handles.edit_1ymin,'String'));
    ymax = str2double(get(handles.edit_1ymax,'String'));
    xlim([xmin xmax])
    ylim([ymin ymax])
else
    mainHandles = guidata(handles.cancerFit);
    ydata = mainHandles.all_obs(2:end,:);
    ymax = max(max(ydata));
    ymin = min(ydata(find(ydata)));
    xlim([1 50])
    ylim([max(ymin/10,1E-10) ymax*10])    
end
guidata(hObject, handles);

% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in pushbutton5.
function pushbutton5_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)



function edit_1xmin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_1xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(hObject,'String'));
xmax = str2double(get(handles.edit_1xmax,'String'));
ymin = str2double(get(handles.edit_1ymin,'String'));
ymax = str2double(get(handles.edit_1ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_1xmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_1xmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_1xmax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_1xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_1xmin,'String'));
xmax = str2double(get(hObject,'String'));
ymin = str2double(get(handles.edit_1ymin,'String'));
ymax = str2double(get(handles.edit_1ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_1xmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_1xmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_1ymin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_1ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_1xmin,'String'));
xmax = str2double(get(handles.edit_1xmax,'String'));
ymin = str2double(get(hObject,'String'));
ymax = str2double(get(handles.edit_1ymax,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_1ymin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_1ymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_1ymax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_1ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1);
xmin = str2double(get(handles.edit_1xmin,'String'));
xmax = str2double(get(handles.edit_1xmax,'String'));
ymin = str2double(get(handles.edit_1ymin,'String'));
ymax = str2double(get(hObject,'String'));
xlim([xmin xmax])
ylim([ymin ymax])
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_1ymax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_1ymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox_1manual_limits.
function checkbox_1manual_limits_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_1manual_limits (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if (get(hObject,'Value') == get(hObject,'Max'))
	% Checkbox is checked-take approriate action
    set(handles.edit_1xmin,'String','0','Enable','On');
    set(handles.edit_1xmax,'String','110','Enable','On');
    set(handles.edit_1ymin,'String','1E-12','Enable','On');
    set(handles.edit_1ymax,'String','1E4','Enable','On');
else
	% Checkbox is not checked-take approriate action
    set(handles.edit_1xmin,'String','0','Enable','Off');
    set(handles.edit_1xmax,'String','110','Enable','Off');
    set(handles.edit_1ymin,'String','1E-12','Enable','Off');
    set(handles.edit_1ymax,'String','1E4','Enable','Off');
end


% --------------------------------------------------------------------
function file_menu_Callback(hObject, eventdata, handles)
% hObject    handle to file_menu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)




% TODO: Add export feature to Menu Bar
% --------------------------------------------------------------------
function export_Callback(hObject, eventdata, handles)
% hObject    handle to export (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[filename, pathname] = uiputfile(...
 {'*.m';'*.mdl';'*.mat';'*.*'},...
 'Save as');
% If "Cancel" is selected then return
if isequal([filename,pathname],[0,0])
    return
% Otherwise construct the fullfilename and Check and load the file
else
    File = fullfile(pathname,filename);
end 
mainHandles = handles.mainHandles;
eval(['save ' File ' handles mainHandles'])

% TODO: Add copy to clipboard feature to Menu Bar
% --------------------------------------------------------------------
function copy_clip_Callback(hObject, eventdata, handles)
% hObject    handle to copy_clip (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
mainHandles = guidata(handles.cancerFit);
best_fits = squeeze(mainHandles.top_fits(mainHandles.selected_row,1:mainHandles.num_fits,:));
clipboard('copy',mat2str(best_fits))

% --------------------------------------------------------------------
function close_Callback(hObject, eventdata, handles)
% hObject    handle to close (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% TODO: Add copy figure to clipboard feature to Menu Bar
% --------------------------------------------------------------------
function copy_fig_Callback(hObject, eventdata, handles)
% hObject    handle to copy_fig (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
axes(handles.axes1)
print(gcf, '-dmeta');
